<template>
    <!-- 视频播放器容器 -->
    <video :id="videoInfo.styleId" class="video-js" controls preload="auto" width="100%" height="100%" data-setup="{}">
        <!-- 视频源，指定视频文件和类型 -->
        <!-- <source :src="url" type="application/x-mpegURL" /> -->
    </video>
</template>

<script>
export default {
    name: 'VideoComponent',
    props: {
        videoInfo: {
            default: () => { },
            type: Object
        }
    },
    data() {
        return {
            player1: null,
            player2: null,
            id: 0
        }
    },
    watch: {
        videoInfo: {
            handler(nVal, oVal) {
                this.id = nVal.id
                this.getUrlAndPlay(nVal.code, nVal.id)
            },
            immediate: true,
            deep: true
        }
    },
    mounted() {
        // this.createVideo()
        // this.getUrlAndPlay()
    },
    methods: {
        // 视频获取
        getUrlAndPlay(code, id) {
            // 保存信息
            if (code) {
                let data = this.qs.stringify({
                    code: code,
                    scheme: 'RTSP'
                })
                let param = {
                    url: '${portal}/biz/catalog/base/point/previewURLs',
                    data,
                    method: 'post',
                    headers: {
                        'Content-type': 'application/x-www-form-urlencoded'
                    }
                }
                this.$http.request(param).then(
                    (resp) => {
                        if (resp.data && resp.data.value) {
                            let value = JSON.parse(resp.data.value)
                            this.$nextTick(() => {
                                // this.createVideo(url, id)
                                this.createVideo(value.url, id)
                            })

                        }
                    },
                    (error) => {
                        this.$message({
                            message: '获取播放地址失败，请重试！',
                            type: 'error'
                        })
                    })
            }
        },
        createVideo(url, id) {
            this[`player${id}`] = this.$video(document.getElementById(`${this.videoInfo.styleId}`), {
                autoplay: true,
                muted: true,
                height: 300,
                width: 300,
                loop: true,
                sources: [{
                    src: url,
                    type: 'application/x-mpegURL'
                }]
            })
        },
    },
    beforeDestroy() {
        if (this[`player${this.id}`]) {
            this[`player${this.id}`]?.dispose()
            this[`player${this.id}`] = null
        }
    }
}
</script>
<style lang="scss" scoped>
.video-js {
    width: 100%;
    height: 100%;

    ::v-deep.vjs-big-play-button // ::v-deep.vjs-icon-placeholder:before

        {
        display: none !important;
    }
}
</style>